@@ -1,10 +1,12 @@
-splitBy<-function (formula, data = parent.frame())
+splitBy<-function (formula, data = parent.frame(),drop=FALSE)
 {
     mf <- match.call(expand.dots = FALSE)
+    #print(mf)
     m <- match(c("formula", "data", "subset", "weights", "na.action",
         "offset"), names(mf), 0)
-    ff <- as.formula(eval(mf[[2]]))
-
+    ##ff <- as.formula(eval(mf[[2]]))
+    ff <- as.formula(eval.parent(mf[[2]]))
+    #print(ff)
     if (ff[[2]]==1){
       #print("JKLJLJLW")
       groupData <- list(data)
@@ -13,7 +15,7 @@ splitBy<-function (formula, data = parent.frame())
       ff <- terms(ff, data = data)
       m <- match.call(expand.dots = TRUE)
       group <- attr(terms(ff), "term.labels")
-      groupData <- split(data, data[, group])
+      groupData <- split(data, data[, group],drop=drop)
       groupid<-lapply(groupData,function(x)x[1,group])
       names(groupid)<-NULL
       groupid<-as.data.frame(do.call('rbind',groupid))
